function Settings() {
	this.debug = false;
	this.version = '4.0';
	this.enableSockets = false;
	this.hideSelfPopup = true;
	this.showConfirmation = true;
	this.labelFormat = '[AVATAR USER] TIMESTAMP:';
	this.maxMessageSize = 500;
	this.maxMessageCount = 1000;
	this.helpUrl = '';
	this.userListAutoExpand = false;
	this.msgRequestInterval = 3;
	this.msgRequestIntervalAway = 5;
	this.floodInterval = 1;
	this.inactivityInterval = 36000; //10 hours
	this.roomTitleFormat = 'ROOM_LABEL - USER_COUNT';
	this.maxUsersPerRoom = 20;
	this.listOrder = 'ENTRY';
	this.disabledIRC = '';
	this.defaultRoom = 1;
	this.defaultTheme = 'navy';
	this.defaultSkin = 'default_skin';
	this.defaultLanguage = 'en';
	this.allowLanguage = true;
	this.splashWindow  = false;

	this.layouts = new Array();
	this.layouts[0] = new CLayout();
	this.layout = this.layouts[0];

	this.smiles = new Object();
	this.extendedSmiles = new Object();
	
	this.sound = new Object();
	this.sound_options = new Object();
	
	this.avatars = new CAvatars();
	this.text = new CText();
	
	this.special_language = new Object();
	
	//Big Skin (like xp_skin, ...)
	this.bigSkin = new Object();
	this.bigSkin.defaultSkin = 0;
	this.bigSkin.preset = new Array();
	this.bigSkin.preset.push(new CBigSkin());
	
	//Simply Skin (like navy, ...)
	this.skin = new Object();
	this.skin.defaultSkin = 0;
	this.skin.preset = new Array();
	this.skin.preset.push(new CSkin());
	
	this.languages = new Array();
	this.languages.push(new CLanguage());
	
	this.user = new Object();
	this.user.skin = null;
	this.user.sound = null;
	
	//logout
	this.logout = new Object();
	//module
	this.module = new Object();
};

Settings.prototype = new Initable();

Settings.prototype.init = function(xml) {
	//trace(' BIG XML ');
	//trace(xml);
	
	this.copyAttrs(xml, this);
	
	var defaultSkin = xml.attributes.defaultTheme;
	var defaultBigSkin = xml.attributes.defaultSkin;

	var skinNumb = 0;
	var langNumb = 0;
	var layoutNumb = 0;
	var bigSkinNumb = 0;
	
	for (var i = 0; i<xml.childNodes.length; i++) {
		var node = xml.childNodes[i];
		
		if(node.nodeType == 1) {
			
			switch(node.nodeName) {
				case 'smiles': 
					this.copyAllAttrs(node, this.smiles);
					SmileTextConst.setNewPattern(this.smiles);
					break;
				case 'sound': 
					this.copyAllAttrs(node, this.sound); 
					break;
				case 'language': 
					if(this.languages[langNumb]) {
						this.languages[langNumb].init(node);
					} else {
						var lang = new CLanguage();
						lang.init(node);
						this.languages.push(lang); 
					}
					langNumb++;
					break;
				case 'skin':
					if(this.bigSkin.preset[bigSkinNumb]) {
						this.bigSkin.preset[bigSkinNumb].init(node); 
					} else {
	 					var bigSkin = new CBigSkin();
						bigSkin.init(node);
						this.bigSkin.preset.push(bigSkin); 
					}

					if(this.bigSkin.preset[bigSkinNumb].swf_name == defaultBigSkin) this.bigSkin.defaultSkin = bigSkinNumb;
					
					bigSkinNumb++;
					break;
				
				case 'theme':
					if(this.skin.preset[skinNumb]) {
						this.skin.preset[skinNumb].init(node); 
					} else {
	 					var skin = new CSkin();
						skin.init(node);
						this.skin.preset.push(skin); 
					}
					
					if(this.skin.preset[skinNumb].id == defaultSkin) this.skin.defaultSkin = skinNumb;
					
					skinNumb++;
					break;
				case 'layout':
					if(this.layouts[layoutNumb]) {
						this.layouts[layoutNumb].init(node); 
					} else {
	 					var layout = new CLayout();
						layout.init(node);
						this.layouts.push(layout); 
					}
					
					layoutNumb++;
					break;
				case 'sound_options' : 
					this.copyAllAttrs(node, this.sound_options);					
					break;
				case 'text' : 
					this.text.init(node);
					break;
				case 'special_language' : 
					this.copyAllAttrs(node, this.special_language);
					break;
				case 'extendedSmiles' : //now disabled
					/*
					for (var j = node.childNodes.length-1; j >= 0; j--)
					{
						var itm = node.childNodes[j];
						if(itm.nodeType == 1)
						{
							this.extendedSmiles[itm.nodeName] = new Object();
							this.copyAllAttrs(itm, this.extendedSmiles[itm.nodeName]);
						}
					}
					SmileTextConst.setExtendedPattern(this.extendedSmiles);*/
					break;
				case 'logout' : 
					this.copyAllAttrs(node, this.logout);
					break;
				case 'module' : 					
					this.copyAllAttrs(node, this.module);
					break;
				case 'avatars' :
					this.avatars.init(node);
					break;
			}
		}
	}
	
	//trace(' SETTINGS ');
	//dbg(this);
};